@@ -1,4 +1,12 @@
 import os.path
+import subprocess
+import sys
+
+def run_except_on_windows(commandline, env=None):
+    if os.name != "nt" and sys.platform != "cygwin":
+        # Strange failures on windows/cygin/mingw
+        subprocess.check_call(commandline, env=env, shell=True)
+        print("  Finished running: " + commandline)
 
 # Test import of same modules from different packages
 testname = os.path.basename(os.path.dirname(os.path.abspath(__file__)))
@@ -10,10 +18,9 @@ print "  Finished importing pkg2.foo"
 var2 = pkg2.foo.Pkg2_Foo()
 
 classname = str(type(var2))
-# Check for an old-style class if swig was run in -classic mode
-if classname == "<type 'instance'>":
-    classname = str(var2.__class__)
-
 if classname.find("pkg2.foo.Pkg2_Foo") == -1:
     raise RuntimeError("failed type checking: " + classname)
 print "  Successfully created object pkg2.foo.Pkg2_Foo"
+
+commandline = sys.executable + " -m pkg2.foo"
+run_except_on_windows(commandline)
