@@ -3,7 +3,7 @@
 require "tests.php";
 require "argout.php";
 
-check::functions(array(incp,incr,inctr,new_intp,copy_intp,delete_intp,intp_assign,intp_value,voidhandle,handle));
+check::functions(array('incp','incr','inctr','new_intp','copy_intp','delete_intp','intp_assign','intp_value','voidhandle','handle'));
 
 $ip=copy_intp(42);
 check::equal(42,incp($ip),"42==incp($ip)");
@@ -23,15 +23,16 @@ check::equal(5,intp_value($tr),"5==$tr");
 
 # Check the voidhandle call, first with null
 unset($handle);
-voidhandle(&$handle);
-check::resource($handle,"_p_void",'$handle is not _p_void');
-$handledata=handle($handle);
-check::equal($handledata,"Here it is","\$handledata != \"Here it is\"");
+# FIXME: Call-time pass-by-reference has been deprecated for ages, and was
+# removed in PHP 5.4.  We need to rework 
+#voidhandle(&$handle);
+#check::resource($handle,"_p_void",'$handle is not _p_void');
+#$handledata=handle($handle);
+#check::equal($handledata,"Here it is","\$handledata != \"Here it is\"");
 
-unset($handle);
-// without reference, should fatal error so can't test here
-//voidhandle($handle);
-//check::isnull($handle,'$handle not null');
+$handle=NULL;
+voidhandle($handle);
+check::isnull($handle,'$handle not null');
 
 check::done();
 ?>
