@@ -4,9 +4,9 @@ require "tests.php";
 require "director_stl.php";
 
 // No new functions
-check::functions(array(foo_bar,foo_ping,foo_pong,foo_tping,foo_tpong,foo_pident,foo_vident,foo_vsecond,foo_tpident,foo_tvident,foo_tvsecond,foo_vidents,foo_tvidents));
+check::functions(array('foo_bar','foo_ping','foo_pong','foo_tping','foo_tpong','foo_pident','foo_vident','foo_vsecond','foo_tpident','foo_tvident','foo_tvsecond','foo_vidents','foo_tvidents'));
 // No new classes
-check::classes(array(Foo));
+check::classes(array('Foo'));
 // now new vars
 check::globals(array());
 
