@@ -255,7 +255,7 @@ public:
     if (goops) {
       if (linkage != GUILE_LSTYLE_PASSIVE && linkage != GUILE_LSTYLE_MODULE) {
 	Printf(stderr, "guile: GOOPS support requires passive or module linkage\n");
-	exit(1);
+	SWIG_exit(EXIT_FAILURE);
       }
     }
 
@@ -322,8 +322,7 @@ public:
 
     Swig_banner(f_begin);
 
-    Printf(f_runtime, "\n");
-    Printf(f_runtime, "#define SWIGGUILE\n");
+    Printf(f_runtime, "\n\n#ifndef SWIGGUILE\n#define SWIGGUILE\n#endif\n\n");
 
     /* Write out directives and declarations */
 
@@ -1300,13 +1299,13 @@ public:
     char *name = GetChar(n, "name");
     char *iname = GetChar(n, "sym:name");
     SwigType *type = Getattr(n, "type");
-    String *value = Getattr(n, "value");
+    String *rawval = Getattr(n, "rawval");
+    String *value = rawval ? rawval : Getattr(n, "value");
     int constasvar = GetFlag(n, "feature:constasvar");
 
 
     String *proc_name;
     String *var_name;
-    String *rvalue;
     Wrapper *f;
     SwigType *nctype;
     String *tm;
@@ -1334,23 +1333,14 @@ public:
     }
     // See if there's a typemap
 
-    bool is_enum_item = (Cmp(nodeType(n), "enumitem") == 0);
-    if (SwigType_type(nctype) == T_STRING) {
-      rvalue = NewStringf("\"%s\"", value);
-    } else if (SwigType_type(nctype) == T_CHAR && !is_enum_item) {
-      rvalue = NewStringf("\'%s\'", value);
-    } else {
-      rvalue = NewString(value);
-    }
-
     if ((tm = Swig_typemap_lookup("constant", n, name, 0))) {
-      Replaceall(tm, "$source", rvalue);
-      Replaceall(tm, "$value", rvalue);
+      Replaceall(tm, "$source", value);
+      Replaceall(tm, "$value", value);
       Replaceall(tm, "$target", name);
       Printv(f_header, tm, "\n", NIL);
     } else {
       // Create variable and assign it a value
-      Printf(f_header, "static %s = (%s)(%s);\n", SwigType_str(type, var_name), SwigType_str(type, 0), rvalue);
+      Printf(f_header, "static %s = (%s)(%s);\n", SwigType_str(type, var_name), SwigType_str(type, 0), value);
     }
     {
       /* Hack alert: will cleanup later -- Dave */
@@ -1370,7 +1360,6 @@ public:
     Delete(var_name);
     Delete(nctype);
     Delete(proc_name);
-    Delete(rvalue);
     DelWrapper(f);
     return SWIG_OK;
   }
