@@ -20,7 +20,7 @@
 extern "C" {
 #endif
   extern int Preprocessor_expr(String *s, int *error);
-  extern char *Preprocessor_expr_error(void);
+  extern const char *Preprocessor_expr_error(void);
   extern Hash *Preprocessor_define(const_String_or_char_ptr str, int swigmacro);
   extern void Preprocessor_undef(const_String_or_char_ptr name);
   extern void Preprocessor_init(void);
